@@ -43,9 +43,9 @@ def save(ctx, message, push):
                             click.echo("- " + conflict_file)
                         click.echo('Please fix conflicts then use "gt save -p" again')    
                 else:
+                    click.echo('Pushing to remote repository...')
                     repo.git.push()
-
-
+                    click.echo('Done!')
             else:
                 click.echo('Remote repository does not exist!')
     else:
